==> qtjambi-xml-6.2.12-sources.jar: io/qt/xml/QDomNodeList.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>List of QDomNode objects</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qdomnodelist.html">QDomNodeList</a></p>
 */
public class QDomNodeList extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#QDomNodeList">QDomNodeList::QDomNodeList()</a></p>
     */
    public QDomNodeList(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomNodeList instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#QDomNodeList-1">QDomNodeList::QDomNodeList(QDomNodeList)</a></p>
     */
    public QDomNodeList(io.qt.xml.@NonNull QDomNodeList arg__1){
        super((QPrivateConstructor)null);
        initialize_native(this, arg__1);
    }
    
    private native static void initialize_native(QDomNodeList instance, io.qt.xml.QDomNodeList arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#at">QDomNodeList::at(int)const</a></p>
     */
    @QtUninvokable
    public final io.qt.xml.@NonNull QDomNode at(int index){
        return at_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @QtUninvokable
    private native io.qt.xml.QDomNode at_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#count">QDomNodeList::count()const</a></p>
     */
    @QtUninvokable
    public final int count(){
        return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int count_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#isEmpty">QDomNodeList::isEmpty()const</a></p>
     */
    @QtUninvokable
    public final boolean isEmpty(){
        return isEmpty_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isEmpty_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#item">QDomNodeList::item(int)const</a></p>
     */
    @QtUninvokable
    public final io.qt.xml.@NonNull QDomNode item(int index){
        return item_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @QtUninvokable
    private native io.qt.xml.QDomNode item_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#length">QDomNodeList::length()const</a></p>
     */
    @QtUninvokable
    public final int length(){
        return length_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int length_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#operator-eq">QDomNodeList::operator=(QDomNodeList)</a></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomNodeList arg__1){
        assign_native_cref_QDomNodeList(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomNodeList(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#operator-eq-eq">QDomNodeList::operator==(QDomNodeList)const</a></p>
     */
    @QtUninvokable
    private final boolean operator_equal(io.qt.xml.@NonNull QDomNodeList arg__1){
        return operator_equal_native_cref_QDomNodeList_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native boolean operator_equal_native_cref_QDomNodeList_constfct(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#size">QDomNodeList::size()const</a></p>
     */
    @QtUninvokable
    public final int size(){
        return size_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int size_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QDomNodeList(QPrivateConstructor p) { super(p); } 
    

    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.xml.QDomNodeList) {
            return operator_equal((io.qt.xml.QDomNodeList) other);
        }

        return false;
    }


    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    @QtUninvokable
    @Override
    public QDomNodeList clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomNodeList clone_native(long __this_nativeId);
}

==> qtjambi-xml-6.4.2-sources.jar: io/qt/xml/QDomNodeList.java <==
package io.qt.xml;


/**
 * <p>List of QDomNode objects</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qdomnodelist.html">QDomNodeList</a></p>
 */
public class QDomNodeList extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#QDomNodeList">QDomNodeList::QDomNodeList()</a></p>
     */
    public QDomNodeList(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomNodeList instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#QDomNodeList-1">QDomNodeList::QDomNodeList(QDomNodeList)</a></p>
     */
    public QDomNodeList(io.qt.xml.QDomNodeList arg__1){
        super((QPrivateConstructor)null);
        initialize_native(this, arg__1);
    }
    
    private native static void initialize_native(QDomNodeList instance, io.qt.xml.QDomNodeList arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#at">QDomNodeList::at(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.xml.QDomNode at(int index){
        return at_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QDomNode at_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#count">QDomNodeList::count()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int count(){
        return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int count_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#isEmpty">QDomNodeList::isEmpty()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isEmpty(){
        return isEmpty_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isEmpty_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#item">QDomNodeList::item(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.xml.QDomNode item(int index){
        return item_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QDomNode item_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#length">QDomNodeList::length()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int length(){
        return length_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int length_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#operator-eq-eq">QDomNodeList::operator==(QDomNodeList)const</a></p>
     */
    @io.qt.QtUninvokable
    private final boolean operator_equal(io.qt.xml.QDomNodeList arg__1){
        return operator_equal_native_cref_QDomNodeList_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_equal_native_cref_QDomNodeList_constfct(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnodelist.html#size">QDomNodeList::size()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int size(){
        return size_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int size_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDomNodeList(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.xml.QDomNodeList) {
            return operator_equal((io.qt.xml.QDomNodeList) other);
        }

        return false;
    }


    @io.qt.QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    @Override
    public QDomNodeList clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QDomNodeList clone_native(long __this_nativeId);
}
